Module thread_priority::unix [−][src]
This module defines the unix thread control.
The crate’s prelude doesn’t have much control over the unix threads, and this module provides better control over those.
Structs
Copy of the Linux kernel’s sched_attr type
Proxy structure to maintain compatibility between glibc and musl
Enums
Normal (usual) schedule policies
The following “real-time” policies are also supported, for special time-critical applications that need precise control over the way in which runnable processes are selected for execution
Thread schedule policy definition
Functions
Set current thread’s priority.
Sets thread’s priority and schedule policy
Sets thread schedule policy.
Returns current thread id, which is the current OS’s native handle. It may or may not be equal or even related to rust’s thread id, there is absolutely no guarantee for that.
Get current thread’s priority value.
Returns policy parameters (schedule policy and other schedule parameters) for current process
Returns policy parameters (schedule policy and other schedule parameters)
Type Definitions
An alias type for a thread id.