Function thread_priority::windows::set_current_thread_priority_boost
source · [−]Expand description
Disables or enables the ability of the system to temporarily boost the priority of a current thread.
If there’s an error, a result of
GetLastError is returned.
This is a short-hand of the set_thread_priority_boost function for the current thread.