Enum thread_priority::ThreadPriority [−][src]
pub enum ThreadPriority {
Min,
Crossplatform(ThreadPriorityValue),
Os(ThreadPriorityOsValue),
Max,
}Expand description
Thread priority enumeration.
Variants
Min
Holds a value representing the minimum possible priority.
Crossplatform(ThreadPriorityValue)
Tuple Fields
Holds a platform-independent priority value. Usually used when setting a value, for sometimes it is not possible to map the operating system’s priority to this value.
Os(ThreadPriorityOsValue)
Tuple Fields
Holds an operating system specific value. If it is not possible to obtain the
ThreadPriority::Crossplatform variant of the value, this is returned instead.
Max
Holds a value representing the maximum possible priority. Should be used with caution, it solely depends on the target os where the program is going to be running on, how it will behave. On some systems, the whole system may become frozen if not used properly.
Implementations
Sets current thread’s priority to this value.