[][src]Enum thread_priority::windows::WinAPIThreadPriority

#[repr(u32)]pub enum WinAPIThreadPriority {
    BackgroundModeBegin,
    BackgroundModeEnd,
    AboveNormal,
    BelowNormal,
    Highest,
    Idle,
    Lowest,
    Normal,
    TimeCritical,
}

The WinAPI priority representation. Check out MSDN for more info: https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-setthreadpriority

Variants

BackgroundModeBegin

Begin background processing mode. The system lowers the resource scheduling priorities of the thread so that it can perform background work without significantly affecting activity in the foreground.

This value can be specified only if hThread is a handle to the current thread. The function fails if the thread is already in background processing mode.

Warning

Windows Server 2003: This value is not supported.

BackgroundModeEnd

End background processing mode. The system restores the resource scheduling priorities of the thread as they were before the thread entered background processing mode.

This value can be specified only if hThread is a handle to the current thread. The function fails if the thread is not in background processing mode.

Warning

Windows Server 2003: This value is not supported.

AboveNormal

Priority 1 point above the priority class.

BelowNormal

Priority 1 point below the priority class.

Highest

Priority 2 points above the priority class.

Idle

Base priority of 1 for IDLE_PRIORITY_CLASS, BELOW_NORMAL_PRIORITY_CLASS, NORMAL_PRIORITY_CLASS, ABOVE_NORMAL_PRIORITY_CLASS, or HIGH_PRIORITY_CLASS processes, and a base priority of 16 for REALTIME_PRIORITY_CLASS processes.

Lowest

Priority 2 points below the priority class.

Normal

Normal priority for the priority class.

TimeCritical

Base priority of 15 for IDLE_PRIORITY_CLASS, BELOW_NORMAL_PRIORITY_CLASS, NORMAL_PRIORITY_CLASS, ABOVE_NORMAL_PRIORITY_CLASS, or HIGH_PRIORITY_CLASS processes, and a base priority of 31 for REALTIME_PRIORITY_CLASS processes.